@@ -3,7 +3,7 @@ import ipaddress
 import click
 # from defektor_api import ApiException, Slave
 from defektor_api import ApiException
-from defektor_api.models import Slave
+from defektor_api.models import Slave, SSHCredentials
 import dfk.config
 from dfk.cli import DfkCli
 
@@ -25,14 +25,14 @@ def add(address, user, private_key_path, port):
     try:
         address = ipaddress.ip_address(address)
 
-        with open(private_key_path, 'r') as private_key_file:
-            private_key_data = private_key_file.read().replace('\n', '')
+        # with open(private_key_path, 'r') as private_key_file:
+        #     private_key_data = private_key_file.read().replace('\n', '')
 
         # TODO: Add user and remove id!
-        slave = Slave(id=0, address=str(address), credentials=private_key_data)
+        slave = Slave(address=str(address), credentials=SSHCredentials(user, private_key_path))
 
         if port is not None:
-            slave.port = port
+            slave.port = int(port)
 
         add_slave_result = DfkCli.api_instance.slave_add(slave)
         click.echo(add_slave_result)
